@@ -62,18 +62,18 @@ from typeguard import check_type
 
 from ._jsii import *
 
-import aws_cdk.aws_sns_subscriptions
-import aws_cdk.core
+import aws_cdk.aws_sns_subscriptions as _aws_cdk_aws_sns_subscriptions_d19397b0
+import aws_cdk.core as _aws_cdk_core_f4b25747
 
 
 class SnsNotify(
-    aws_cdk.core.Construct,
+    _aws_cdk_core_f4b25747.Construct,
     metaclass=jsii.JSIIMeta,
     jsii_type="cdk-sns-notify.SnsNotify",
 ):
     def __init__(
         self,
-        scope: aws_cdk.core.Construct,
+        scope: _aws_cdk_core_f4b25747.Construct,
         id: builtins.str,
         *,
         line_notify_token: builtins.str,
@@ -84,7 +84,7 @@ class SnsNotify(
         :param line_notify_token: 
         '''
         if __debug__:
-            type_hints = typing.get_type_hints(SnsNotify.__init__)
+            type_hints = typing.get_type_hints(_typecheckingstub__b8ef0c3b3bf76805aeada37f42068a38876b6fa8f48b269bef3b01d34d394866)
             check_type(argname="argument scope", value=scope, expected_type=type_hints["scope"])
             check_type(argname="argument id", value=id, expected_type=type_hints["id"])
         props = SnsNotifyProps(line_notify_token=line_notify_token)
@@ -93,8 +93,10 @@ class SnsNotify(
 
     @builtins.property
     @jsii.member(jsii_name="lambdaSubscription")
-    def lambda_subscription(self) -> aws_cdk.aws_sns_subscriptions.LambdaSubscription:
-        return typing.cast(aws_cdk.aws_sns_subscriptions.LambdaSubscription, jsii.get(self, "lambdaSubscription"))
+    def lambda_subscription(
+        self,
+    ) -> _aws_cdk_aws_sns_subscriptions_d19397b0.LambdaSubscription:
+        return typing.cast(_aws_cdk_aws_sns_subscriptions_d19397b0.LambdaSubscription, jsii.get(self, "lambdaSubscription"))
 
 
 @jsii.data_type(
@@ -108,9 +110,9 @@ class SnsNotifyProps:
         :param line_notify_token: 
         '''
         if __debug__:
-            type_hints = typing.get_type_hints(SnsNotifyProps.__init__)
+            type_hints = typing.get_type_hints(_typecheckingstub__85c73f21e101155acb1fe58f772cfd374076e38c0dacd52491731e5877d4f9cf)
             check_type(argname="argument line_notify_token", value=line_notify_token, expected_type=type_hints["line_notify_token"])
-        self._values: typing.Dict[str, typing.Any] = {
+        self._values: typing.Dict[builtins.str, typing.Any] = {
             "line_notify_token": line_notify_token,
         }
 
@@ -138,3 +140,19 @@ __all__ = [
 ]
 
 publication.publish()
+
+def _typecheckingstub__b8ef0c3b3bf76805aeada37f42068a38876b6fa8f48b269bef3b01d34d394866(
+    scope: _aws_cdk_core_f4b25747.Construct,
+    id: builtins.str,
+    *,
+    line_notify_token: builtins.str,
+) -> None:
+    """Type checking stubs"""
+    pass
+
+def _typecheckingstub__85c73f21e101155acb1fe58f772cfd374076e38c0dacd52491731e5877d4f9cf(
+    *,
+    line_notify_token: builtins.str,
+) -> None:
+    """Type checking stubs"""
+    pass
